@@ -16,12 +16,14 @@ __routes__ = [
 @execute.route('/execute', methods=['POST'])
 @authenticate()
 def execute():
-    """ Endpoint to execute commands """
+    """Endpoint to execute commands"""
     try:
         msg = json.loads(request.data.decode('utf-8'))
     except Exception as e:
-        logger().error('Unable to parse JSON from request {}: {}'.format(request.data, str(e)))
-        return abort(400, str(e))
+        logger().error(
+            'Unable to parse JSON from request {}: {}'.format(request.data, str(e))
+        )
+        abort(400, str(e))
 
     logger().info('Received message on the HTTP backend: {}'.format(msg))
 
@@ -29,8 +31,10 @@ def execute():
         response = send_message(msg)
         return Response(str(response or {}), mimetype='application/json')
     except Exception as e:
-        logger().error('Error while running HTTP action: {}. Request: {}'.format(str(e), msg))
-        return abort(500, str(e))
+        logger().error(
+            'Error while running HTTP action: {}. Request: {}'.format(str(e), msg)
+        )
+        abort(500, str(e))
 
 
 # vim:sw=4:ts=4:et:
